@@ -1,8 +1,11 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.55'; # TRIAL
+
 # ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
+
+our $VERSION = '0.63';
+
 use Moose 2.0000;
 use Carp;
 use namespace::autoclean;
@@ -10,14 +13,9 @@ use Sub::Attribute;
 
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
+use Test::Class::Moose::Deprecated;
 
-has 'test_report' => (
-    is     => 'rw',
-    isa    => 'Test::Class::Moose::Report',
-    writer => '__set_test_report',
-);
-
-sub __create_attributes {
+sub __sub_attr_declaration_code {
 
     # XXX sharing this behavior here because my first attempt at creating a
     # role was a complete failure. MooseX::MethodAttributes can help here, but
@@ -104,13 +102,20 @@ DECLARE_ATTRIBUTES
 }
 
 BEGIN {
-    eval __PACKAGE__->__create_attributes;
+    eval __PACKAGE__->__sub_attr_declaration_code;
     croak($@) if $@;
 }
 
+has 'test_report' => (
+    is  => 'ro',
+    isa => 'Test::Class::Moose::Report',
+);
+
 has 'test_class' => (
-    is  => 'rw',
-    isa => 'Str',
+    is       => 'ro',
+    isa      => 'Str',
+    init_arg => undef,
+    default  => sub { ref $_[0] },
 );
 
 has 'test_skip' => (
@@ -153,8 +158,8 @@ END
 # XXX - this is only necessary for backwards compatibility, where people call
 # Test::Class::Moose->new(...)->runtests() instead of
 # Test::Class::Moose::Runner->new(...)->runtests()
-my %config_attrs = map { $_->init_arg => 1}
-    Test::Class::Moose::Config->meta->get_all_attributes;
+my %config_attrs = map { $_->init_arg => 1 }
+  Test::Class::Moose::Config->meta->get_all_attributes;
 around 'BUILDARGS' => sub {
     my $orig  = shift;
     my $class = shift;
@@ -162,7 +167,7 @@ around 'BUILDARGS' => sub {
     my $p = $class->$orig(@_);
 
     my %config_p
-        = map { $_ => delete $p->{$_} } grep { $config_attrs{$_} } keys %{$p};
+      = map { $_ => delete $p->{$_} } grep { $config_attrs{$_} } keys %{$p};
     $p->{_config_p} = \%config_p;
 
     return $p;
@@ -172,31 +177,23 @@ around 'BUILDARGS' => sub {
 sub runtests {
     my $self = shift;
 
-    # The only way this object won't have a _runner set is if someone calls
-    # ->new() on their test class (which subclasses Test::Class::Moose) and
-    # then calls ->runtests() on it, which has never been documented as
-    # working.
-    carp 'Calling runtests() on a Test::Class::Moose object is deprecated.'
-        . ' Use Test::Class::Moose::Runner instead.';
+    Test::Class::Moose::Deprecated::deprecated(
+        message =>
+          'Calling runtests() on a Test::Class::Moose object is deprecated.'
+          . ' Use Test::Class::Moose::Runner instead.',
+        feature => 'Test::Class::Moose->runtests',
+    );
 
     require Test::Class::Moose::Runner;
-    my $runner
-        = Test::Class::Moose::Runner->new( $self->_config_p );
+    my $runner = Test::Class::Moose::Runner->new( $self->_config_p );
 
     return $runner->runtests();
 }
 
-sub BUILD {
-    my $self = shift;
-
-    # stash that name lest something change it later. Paranoid?
-    $self->test_class( $self->meta->name );
-}
-
 sub _tcm_make_test_class_instances {
-    my ( $test_class, $args ) = @_;
+    my $test_class = shift;
 
-    return ( $test_class => $test_class->new($args) );
+    return ( $test_class => $test_class->new(@_) );
 }
 
 sub test_methods {
@@ -209,7 +206,7 @@ sub test_methods {
         next if $method->isa('Moose::Meta::Method::Accessor');
 
         my $class = ref $self;
-        my $name = $method->name;
+        my $name  = $method->name;
         next
           unless $name =~ /^test_/
           || Test::Class::Moose::AttributeRegistry->has_test_attribute(
@@ -237,15 +234,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.55
+version 0.63
 
 =head1 SYNOPSIS
 
@@ -272,7 +267,7 @@ version 0.55
 
 =head1 DESCRIPTION
 
-See the L<Test::Class::Moose home page|http://ovid.github.io/test-class-moose/> for
+See the L<Test::Class::Moose home page|http://test-class-moose.github.io/test-class-moose/> for
 a summary.
 
 C<Test::Class::Moose> is a powerful testing framework for Perl. Out of the box
@@ -301,6 +296,8 @@ you get:
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
+=for Pod::Coverage Tags Tests runtests
+
 =head1 BASICS
 
 =head2 Inheriting from Test::Class::Moose
@@ -309,6 +306,11 @@ Just C<use Test::Class::Moose>. That's all. You'll get all L<Test::Most> test
 functions, too, along with C<strict> and C<warnings>. You can use all L<Moose>
 behavior, too.
 
+When you C<use Test::Class::Moose> it inserts itself as a parent class for
+your test class. This means that if you try to use C<extends> in your test
+class you will break things unless you include C<Test::Class::Moose> as a
+parent. We recommend that you use roles in your test classes instead.
+
 =head2 Declare a test method
 
 All method names that begin with C<test_> are test methods. Methods that do
@@ -441,7 +443,7 @@ C<< $test->test_class >>, or you can do this:
     sub test_startup {
         my $test                 = shift;
         my $report               = $test->test_report;
-        my $class                = $report->current_class->name;
+        my $instance             = $report->current_instance->name;
         my $upcoming_test_method = $report->current_method->name;
         ...
     }
@@ -534,7 +536,9 @@ class's constructor. Here's a really dumb example:
  sub test_something { ... }
 
 The test runner will run all the test methods in your class I<once per
-instance>, and each instance will be run in its own subtest.
+instance>, and each instance will be run in its own subtest. You can
+dynamically decide to skip your test class completely by having
+C<_constructor_parameter_sets> return an empty list.
 
 Note that this feature has great potential for abuse, so use it
 cautiously. That said, there are cases where this feature can greatly simplify
@@ -562,6 +566,10 @@ If you wish to skip a class, set the reason in the C<test_startup> method.
         $test->test_skip("I don't want to run this class");
     }
 
+If you are using L<test class instances|/"TEST CLASS INSTANCES">, you
+can also make C<_constructor_parameter_sets> return an empty list,
+which will result in the class being skipped.
+
 If you wish to skip an individual method, do so in the C<test_setup> method.
 
     sub test_setup {
@@ -691,8 +699,8 @@ You can also call it in test classes (most useful in the C<test_setup()> method)
     sub test_setup {
         my $test = shift;
         $self->next::method;
-        my $report= $test->test_report;
-        my $class = $test->current_class;
+        my $report = $test->test_report;
+        my $instance = $test->current_instance;
         my $method = $test->current_method; # the test method we're about to run
         if ( $method->name =~ /customer/ ) {
             $test->load_customer_fixture;
@@ -800,10 +808,13 @@ wrong).
     foreach my $class ( $report->all_test_instances ) {
         my $class_name = $class->name;
         ok !$class->is_skipped, "$class_name was not skipped";
+        ok $class->passed, "$class_name passed";
 
         subtest "$class_name methods" => sub {
             foreach my $method ( $class->all_test_methods ) {
                 my $method_name = $method->name;
+                ok $method->passed, "$method_name passed";
+
                 ok !$method->is_skipped, "$method_name was not skipped";
                 cmp_ok $method->num_tests, '>', 0,
                   '... and some tests should have been run';
@@ -818,6 +829,7 @@ wrong).
         my $system = $time->system;
         # do with these as you will
     }
+    diag "Number of test classes: "   . $report->num_test_classes;
     diag "Number of test instances: " . $report->num_test_instances;
     diag "Number of test methods: "   . $report->num_test_methods;
     diag "Number of tests:        "   . $report->num_tests;
@@ -958,9 +970,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * GitHub Issues (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Class-Moose>
+L<https://github.com/test-class-moose/test-class-moose/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -970,9 +982,9 @@ L<http://annocpan.org/dist/Test-Class-Moose>
 
 L<http://cpanratings.perl.org/d/Test-Class-Moose>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Test-Class-Moose/>
+L<https://metacpan.org/release/Test-Class-Moose/>
 
 =back
 
@@ -1001,45 +1013,107 @@ L<Test::Class> + L<Test::Most>.
 
 =back
 
-=head1 CONTRIBUTORS
+=head1 AUTHORS
 
 =over 4
 
-=item * Dave Rolsky <autarch@urth.org>
-
-=item * Doug Bell <doug.bell@baml.com>
-
-=item * Gregory Oschwald <goschwald@maxmind.com>
-
-=item * Jonathan C. Otsuka <djgoku@gmail.com>
-
-=item * Neil Bowers <neil@bowers.com>
-
-=item * Olaf Alders <olaf@wundersolutions.com>
-
-=item * Ovid <curtis\_ovid\_poe@yahoo.com>
-
-=item * Paul Boyd <pboyd@dev3l.net>
-
-=item * Petrea Corneliu Stefan <stefan@garage-coding.com>
-
-=item * Stuckdownawell <stuckdownawell@gmail.com>
-
-=item * Tom Beresford <tom.beresford@bskyb.com>
-
-=item * Tom Heady <tom@punch.net>
-
-=item * Udo Oji <Velti@signor.com>
-
-=back
-
-=head1 AUTHOR
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords Andy Jack Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge mark-5 mephinet Neil Bowers Olaf Alders Paul Boyd Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji
+
+=over 4
+
+=item *
+
+Andy Jack <github@veracity.ca>
+
+=item *
+
+Doug Bell <madcityzen@gmail.com>
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Jeremy Krieg <Jeremy.Krieg@YourAmigo.com>
+
+=item *
+
+Jonathan C. Otsuka <djgoku@gmail.com>
+
+=item *
+
+Jonathan Stowe <jns@gellyfish.co.uk>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+mark-5 <maflick88@gmail.com>
+
+=item *
+
+mephinet <mephinet@gmx.net>
+
+=item *
+
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Paul Boyd <pboyd@dev3l.net>
+
+=item *
+
+Petrea Corneliu Stefan <stefan@garage-coding.com>
+
+=item *
+
+Steven Humphrey <catchgithub@33k.co.uk>
+
+=item *
+
+Stuckdownawell <stuckdownawell@gmail.com>
+
+=item *
+
+Tim Vroom <vroom@blockstackers.com>
+
+=item *
+
+Tom Beresford <tom.beresford@bskyb.com>
+
+=item *
+
+Tom Heady <tom@punch.net>
+
+=item *
+
+Udo Oji <Velti@signor.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
