@@ -1,57 +1,70 @@
 package Test::Class::Moose::Load;
-$Test::Class::Moose::Load::VERSION = '0.55'; # TRIAL
+
 # ABSTRACT: Load L<Test::Class::Moose> classes automatically.
 
 use strict;
 use warnings;
 
+our $VERSION = '0.63';
+
 use File::Find;
 use File::Spec;
 
 # Override to get your own filter
 sub is_test_class {
     my ( $class, $file, $dir ) = @_;
+
     # By default, we only care about .pm files
-    if ($file =~ /\.pm$/) {
+    if ( $file =~ /\.pm$/ ) {
         return 1;
     }
     return;
 }
 
 my %Added_to_INC;
+
 sub _load {
     my ( $class, $file, $dir ) = @_;
 
-    $file =~ s{\.pm$}{};             # remove .pm extension
-    $file =~ s{\\}{/}g;              # to make win32 happy
-    $dir  =~ s{\\}{/}g;              # to make win32 happy
+    $file =~ s{\.pm$}{};    # remove .pm extension
+    $file =~ s{\\}{/}g;     # to make win32 happy
+    $dir =~ s{\\}{/}g;      # to make win32 happy
     $file =~ s/^$dir//;
-    my $_package = join '::' => grep $_ => File::Spec->splitdir( $file );
+    my $_package = join '::' => grep $_ => File::Spec->splitdir($file);
 
     # untaint that puppy!
-    my ( $package ) = $_package =~ /^([[:word:]]+(?:::[[:word:]]+)*)$/;
-   
+    my ($package) = $_package =~ /^([[:word:]]+(?:::[[:word:]]+)*)$/;
+
     # Filter out bad classes (mainly this means things in .svn and similar)
     return unless defined $package;
 
-    unshift @INC => $dir unless $Added_to_INC{ $dir }++;
+    unshift @INC => $dir unless $Added_to_INC{$dir}++;
 
-    # either "require" it or "use" it with no import list. Otherwise, this
-    # module will inherit from Test::Class::Moose and break everything.
-    eval "use $package ()"; ## no critic
+    {
+        local $SIG{__DIE__} = sub {
+            undef $SIG{__DIE__};
+            require Carp;
+            local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+            Carp::confess(@_);
+        };
+
+        # either "require" it or "use" it with no import list. Otherwise, this
+        # module will inherit from Test::Class::Moose and break everything.
+        eval "use $package ()";    ## no critic
+    }
     die $@ if $@;
 }
 
 sub import {
     my ( $class, @directories ) = @_;
 
-    foreach my $dir ( @directories ) {
+    foreach my $dir (@directories) {
         $dir = File::Spec->catdir( split '/', $dir );
         find(
             {   no_chdir => 1,
                 wanted   => sub {
-                    my @args = ($File::Find::name, $dir);
-                    if ($class->is_test_class(@args)) {
+                    my @args = ( $File::Find::name, $dir );
+                    if ( $class->is_test_class(@args) ) {
                         $class->_load(@args);
                     }
                 },
@@ -67,15 +80,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose::Load - Load L<Test::Class::Moose> classes automatically.
 
 =head1 VERSION
 
-version 0.55
+version 0.63
 
 =head1 SYNOPSIS
 
@@ -265,13 +276,23 @@ I make changes.
 Thanks to David Wheeler for the idea and Adrian Howard for
 L<Test::Class::Moose>.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
