@@ -1,7 +1,11 @@
 package Test::Class::Moose::Report::Method;
-$Test::Class::Moose::Report::Method::VERSION = '0.55'; # TRIAL
+
 # ABSTRACT: Reporting on test methods
 
+use 5.10.0;
+
+our $VERSION = '0.63';
+
 use Moose;
 use Carp;
 use namespace::autoclean;
@@ -11,7 +15,19 @@ with qw(
   Test::Class::Moose::Role::Reporting
 );
 
-has 'instance_report' => (
+has test_setup_method => (
+    is     => 'rw',
+    isa    => 'Test::Class::Moose::Report::Method',
+    writer => 'set_test_setup_method',
+);
+
+has test_teardown_method => (
+    is     => 'rw',
+    isa    => 'Test::Class::Moose::Report::Method',
+    writer => 'set_test_teardown_method',
+);
+
+has 'instance' => (
     is       => 'ro',
     isa      => 'Test::Class::Moose::Report::Instance',
     required => 1,
@@ -24,11 +40,6 @@ has 'num_tests_run' => (
     default => 0,
 );
 
-sub tests_run {
-    carp "tests_run() deprecated as of version 0.07. Use num_tests_run().";
-    goto &num_tests_run;
-}
-
 has 'tests_planned' => (
     is        => 'rw',
     isa       => 'Int',
@@ -40,18 +51,16 @@ sub plan {
     $self->tests_planned( ( $self->tests_planned || 0 ) + $integer );
 }
 
-sub add_to_plan {
-    my ( $self, $integer ) = @_;
-    carp("add_to_plan() is deprecated. You can now call plan() multiple times");
-    return $self->plan($integer);
-}
-
 sub has_tag {
     my ( $self, $tag ) = @_;
     croak("has_tag(\$tag) requires a tag name") unless defined $tag;
-    my $instance_report = $self->instance_report->name;
-    my $method          = $self->name;
-    return Test::Class::Moose::AttributeRegistry->method_has_tag( $instance_report, $method, $tag );
+    my $class  = $self->instance->class->name;
+    my $method = $self->name;
+    return Test::Class::Moose::AttributeRegistry->method_has_tag(
+        $class,
+        $method,
+        $tag
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -62,27 +71,29 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose::Report::Method - Reporting on test methods
 
 =head1 VERSION
 
-version 0.55
+version 0.63
 
 =head1 DESCRIPTION
 
 Should be considered experimental and B<read only>.
 
+=for Pod::Coverage plan
+
 =head1 IMPLEMENTS
 
 L<Test::Class::Moose::Role::Reporting>.
 
 =head1 ATTRIBUTES
 
-=head2 C<instance_report>
+See L<Test::Class::Moose::Role::Reporting> for additional attributes.
+
+=head2 C<instance>
 
 The L<Test::Class::Moose::Report::Instance> for this method.
 
@@ -100,7 +111,7 @@ The number of tests planned for this test method. If a plan has not been
 explicitly set with C<$report->test_plan>, then this number will always be
 equal to the number of tests run.
 
-=head1 C<has_tag>
+=head2 C<has_tag>
 
     my $method = $test->test_report->current_method;
     if ( $method->has_tag('db') ) {
@@ -109,13 +120,23 @@ equal to the number of tests run.
 
 Returns true if the current test method has the tag in question.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
