@@ -1,8 +1,11 @@
 package Test::Class::Moose::Role::Parallel;
-$Test::Class::Moose::Role::Parallel::VERSION = '0.55'; # TRIAL
+
 # ABSTRACT: Deprecated parallel runner role - see docs for details
 
 use 5.10.0;
+
+our $VERSION = '0.63';
+
 use Moose::Role 2.0000;
 use namespace::autoclean;
 
@@ -10,7 +13,7 @@ requires 'runtests';
 
 before runtests => sub {
     warn
-        "The Test::Class::Moose::Role::Parallel role is deprecated. Use the new Test::Class::Moose::Runner class instead.";
+      "The Test::Class::Moose::Role::Parallel role is deprecated. Use the new Test::Class::Moose::Runner class instead.";
 };
 
 1;
@@ -19,15 +22,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose::Role::Parallel - Deprecated parallel runner role - see docs for details
 
 =head1 VERSION
 
-version 0.55
+version 0.63
 
 =head1 DESCRIPTION
 
@@ -40,13 +41,23 @@ L<Test::Class::Moose::Runner> class:
         jobs => 4,
     )->runtests();
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
