@@ -1,7 +1,11 @@
 package Test::Class::Moose::Tutorial;
-$Test::Class::Moose::Tutorial::VERSION = '0.55'; # TRIAL
+
 # ABSTRACT: A starting guide for Test::Class::Moose
 
+use 5.10.0;
+
+our $VERSION = '0.63';
+
 # there is no code here, but we're moving this from .pod to .pm to try to work
 # around a strange bug where this is showing up instead of main docs on
 # metacpan and cpan
@@ -12,15 +16,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose::Tutorial - A starting guide for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.55
+version 0.63
 
 =head1 Getting Started
 
@@ -153,7 +155,7 @@ inspect your test environment.
 =head1 Test Class Composition
 
 The most important reason to choose a class test over a procedural test (using
-only C<Test::More>) is class composition. 
+only C<Test::More>) is class composition.
 
 =head2 Inheritance
 
@@ -249,7 +251,7 @@ and call the C<test_skip> method with the reason we're skipping the test.
         my ( $test ) = @_;
         fail "This doesn't work!";
     }
-    
+
     sub test_setup {
         my $test = shift;
         if ( $test->test_report->current_method->name eq 'test_will_fail' ) {
@@ -361,13 +363,23 @@ Here is the bare minimum you need to get started using C<Test::Class::Moose>
 
 Doug Bell: https://github.com/preaction
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
